@@ -24,13 +24,11 @@ def video_key(video):
         video.find("facets") is not None and any((f.text == "progressive" for f in video.facets.facet))
     )
 
-def get_id(url):
-    try:
-        return int(url)
-    except ValueError:
-        pass
+def video_valid(video):
+    return (video.url.text.startswith("http") and v.url.text.endswith(".mp4"))
 
-    return int(re.search(r"beitrag/video/([0-9]+)/", url).group(1))
+def get_id(url):
+    return int(re.search(r"[^0-9]*([0-9]+)[^0-9]*", url).group(1))
 
 def format_mb(bytes):
     return "%.2f" % (bytes/(1024*1024))
@@ -54,7 +52,7 @@ def main():
     print(video.information.title.text)
     print("  %s" % video.details.vcmsUrl.text)
 
-    videos = [v for v in video.formitaeten.formitaet if v.url.text.startswith("http")]
+    videos = [v for v in video.formitaeten.formitaet if video_valid(v)]
     videos.sort(key=video_key, reverse=True)
 
     for v in videos:
